<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="uk">
<context>
    <name>AddPluginDialog</name>
    <message>
        <source>Add plugins</source>
        <translation type="obsolete">Додати плаґіни</translation>
    </message>
    <message>
        <source>Search:</source>
        <translation type="vanished">Шукати:</translation>
    </message>
    <message>
        <source>Add plugin</source>
        <translation type="obsolete">Додати плаґін</translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="vanished">Закрити</translation>
    </message>
</context>
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="../../configdialog/lxqtconfigdialog.ui" line="14"/>
        <source>Dialog</source>
        <translation>Діалог</translation>
    </message>
</context>
<context>
    <name>LXQt::AboutDialogPrivate</name>
    <message>
        <source>Version: %1</source>
        <translation type="vanished">Версія: %1</translation>
    </message>
    <message>
        <source>Advanced, easy-to-use, and fast desktop environment based on Qt technologies.</source>
        <comment>About dialog, &apos;About&apos; tab text</comment>
        <translation type="vanished">Передове, легке у використанні та швидке стільникове середовище засноване на технологіях Qt.</translation>
    </message>
    <message>
        <source>Copyright: %1-%2 %3</source>
        <comment>About dialog, &apos;About&apos; tab text</comment>
        <translation type="vanished">Авторське право: %1-%2 %3</translation>
    </message>
    <message>
        <source>Homepage: %1</source>
        <comment>About dialog, &apos;About&apos; tab text</comment>
        <translation type="vanished">Домашня сторінка: %1</translation>
    </message>
    <message>
        <source>License: %1</source>
        <comment>About dialog, &apos;About&apos; tab text</comment>
        <translation type="vanished">Ліцензія: %1</translation>
    </message>
    <message>
        <source>LXQt is translated into many languages thanks to the work of the translation teams all over the world.</source>
        <comment>About dialog, &apos;Translations&apos; tab text</comment>
        <translation type="vanished">LXQt перекладено на багато мов завдяки праці команд перекладачів по всьому світу.</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation type="obsolete">Так</translation>
    </message>
    <message>
        <source>No</source>
        <translation type="obsolete">Ні</translation>
    </message>
    <message>
        <source>&lt;b&gt;LXQt Desktop Toolbox - Technical Info&lt;/b&gt;</source>
        <translation type="obsolete">&lt;b&gt;Інструменти стільниці LXQt - Технічна інформація&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Version</source>
        <translation type="obsolete">Версія</translation>
    </message>
    <message>
        <source>Qt</source>
        <translation type="obsolete">Qt</translation>
    </message>
    <message>
        <source>Debug Build</source>
        <translation type="obsolete">Відлагоджувальна збірка</translation>
    </message>
    <message>
        <source>System Configuration</source>
        <translation type="obsolete">Сістемні налаштування</translation>
    </message>
    <message>
        <source>Share Directory</source>
        <translation type="obsolete">Спільна тека</translation>
    </message>
    <message>
        <source>Translations</source>
        <comment>About dialog, Tab title</comment>
        <translation type="obsolete">Переклади</translation>
    </message>
    <message>
        <source>&lt;b&gt;User Directories&lt;/b&gt;</source>
        <translation type="obsolete">&lt;b&gt;Теки користувача&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Xdg Data Home</source>
        <translation type="obsolete">Домівка даних Xdg</translation>
    </message>
    <message>
        <source>Xdg Config Home</source>
        <translation type="obsolete">Домівка налаштувань Xdg</translation>
    </message>
    <message>
        <source>Xdg Data Dirs</source>
        <translation type="obsolete">Текі даних Xdg</translation>
    </message>
    <message>
        <source>Xdg Cache Home</source>
        <translation type="obsolete">Домівка кешу Xdg</translation>
    </message>
    <message>
        <source>Xdg Runtime Home</source>
        <translation type="obsolete">Домівка часу виконання Xdg</translation>
    </message>
    <message>
        <source>Xdg Autostart Dirs</source>
        <translation type="obsolete">Текі автозапуску Xdg</translation>
    </message>
    <message>
        <source>Xdg Autostart Home</source>
        <translation type="obsolete">Домівка автозапуску Xdg</translation>
    </message>
</context>
<context>
    <name>LXQt::MessageBox</name>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="74"/>
        <source>LXQt Power Manager Error</source>
        <translation>Збій менеджера живлення LXQt</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="74"/>
        <source>Hibernate failed.</source>
        <translation>Не вдалося приспати.</translation>
    </message>
</context>
<context>
    <name>LXQt::NotificationPrivate</name>
    <message>
        <location filename="../../lxqtnotification.cpp" line="152"/>
        <source>Notifications Fallback</source>
        <translation>Резервне сповіщення</translation>
    </message>
</context>
<context>
    <name>LXQt::PowerManager</name>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="117"/>
        <source>Hibernate</source>
        <translation>Приспати</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="124"/>
        <source>Suspend</source>
        <translation>Призупинити</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="131"/>
        <source>Reboot</source>
        <translation>Перезавантажити</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="138"/>
        <source>Shutdown</source>
        <translation>Вимкнути</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="145"/>
        <source>Logout</source>
        <translation>Вийти</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="157"/>
        <source>LXQt Session Suspend</source>
        <translation>Призупинити комп’ютер</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="158"/>
        <source>Do you want to really suspend your computer?&lt;p&gt;Suspends the computer into a low power state. System state is not preserved if the power is lost.</source>
        <translation>Дійсно призупинити комп’ютер?&lt;p&gt;Це переведе його в режим зниженого енергоспоживання. При втраті живлення стан системи не збережеться.</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="167"/>
        <source>LXQt Session Hibernate</source>
        <translation>Приспати комп’ютер</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="168"/>
        <source>Do you want to really hibernate your computer?&lt;p&gt;Hibernates the computer into a low power state. System state is preserved if the power is lost.</source>
        <translation>Дійсно приспати комп’ютер?&lt;p&gt;Це переведе його в режим зниженого енергоспоживання. При втраті живлення стан системи збережеться.</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="177"/>
        <source>LXQt Session Reboot</source>
        <translation>Перезавантажити комп’ютер</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="178"/>
        <source>Do you want to really restart your computer? All unsaved work will be lost...</source>
        <translation>Дійсно перезавантажити комп’ютер? Усю незбережену роботу буде втрачено...</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="187"/>
        <source>LXQt Session Shutdown</source>
        <translation>Вимкнути комп’ютер</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="188"/>
        <source>Do you want to really switch off your computer? All unsaved work will be lost...</source>
        <translation>Дійсно вимкнути комп’ютер? Усю незбережену роботу буде втрачено...</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="197"/>
        <source>LXQt Session Logout</source>
        <translation>Вийти з сеансу LXQt</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="198"/>
        <source>Do you want to really logout? All unsaved work will be lost...</source>
        <translation>Дійсно завершити сеанс? Усю незбережену роботу буде втрачено...</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="206"/>
        <location filename="../../lxqtpowermanager.cpp" line="211"/>
        <source>LXQt Power Manager Error</source>
        <translation>Збій менеджера живлення LXQt</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="206"/>
        <source>Hibernate failed.</source>
        <translation>Не вдалося приспати.</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="211"/>
        <source>Suspend failed.</source>
        <translation>Не вдалося призупинити.</translation>
    </message>
</context>
<context>
    <name>LXQt::ScreenSaver</name>
    <message>
        <location filename="../../lxqtscreensaver.cpp" line="236"/>
        <source>Lock Screen</source>
        <translation>Заблокувати екран</translation>
    </message>
    <message>
        <location filename="../../lxqtscreensaver.cpp" line="156"/>
        <source>Screen Saver Error</source>
        <translation>Помилка зберігача екрану</translation>
    </message>
    <message>
        <location filename="../../lxqtscreensaver.cpp" line="162"/>
        <location filename="../../lxqtscreensaver.cpp" line="168"/>
        <location filename="../../lxqtscreensaver.cpp" line="175"/>
        <source>Screen Saver Activation Error</source>
        <translation>Збій запуску зберігача екрану</translation>
    </message>
    <message>
        <location filename="../../lxqtscreensaver.cpp" line="176"/>
        <source>An error occurred starting screensaver. Unknown error - undocumented return value from xdg-screensaver: %1.</source>
        <translation>Сталася помилка під час запуску зберігача екрану. Невідома помилка - недокументоване значення виводу xdg-screensaver: %1. </translation>
    </message>
    <message>
        <source>An error occurred starting screensaver. xdg-screensaver cannot be started due its crash.</source>
        <translation type="vanished">Стався збій при запуску зберігача екрану. xdg-screensaver зазнав краху.</translation>
    </message>
    <message>
        <source>An error occurred starting screensaver. xdg-screensaver is not installed correctly.</source>
        <translation type="vanished">Стався збій при запуску зберігача екрану. xdg-screensaver не встановлено коректним чином.</translation>
    </message>
    <message>
        <source>An error occurred starting screensaver. xdg-screensaver cannot be started.</source>
        <translation type="vanished">Стався збій при запуску зберігача екрану. Не вдалося запустити xdg-screensaver.</translation>
    </message>
    <message>
        <location filename="../../lxqtscreensaver.cpp" line="157"/>
        <source>An error occurred starting screensaver. Syntax error in xdg-screensaver arguments.</source>
        <translation>Стався збій при запуску зберігача екрану. В аргументах xdg-screensaver синтаксична помилка.</translation>
    </message>
    <message>
        <location filename="../../lxqtscreensaver.cpp" line="163"/>
        <source>An error occurred starting screensaver. Ensure you have xscreensaver installed and running.</source>
        <translation>Стався збій при запуску зберігача екрану. Впевніться, що xscreensaver коректно встановлено та запущено.</translation>
    </message>
    <message>
        <location filename="../../lxqtscreensaver.cpp" line="169"/>
        <source>An error occurred starting screensaver. Action &apos;activate&apos; failed. Ensure you have xscreensaver installed and running.</source>
        <translation>Стався збій при запуску зберігача екрану. Не вдалося виконати дію &quot;activate&quot;. Впевніться, що xscreensaver коректно встановлено та запущено.</translation>
    </message>
    <message>
        <source>An error occurred starting screensaver. Unknown error - undocumented return value from xdg-screensaver=%1.</source>
        <translation type="vanished">Стався збій при запуску зберігача екрану. Невідома помилка - xdg-screensaver повернув недокументоване значення = %1.</translation>
    </message>
</context>
<context>
    <name>LXQt::ShortcutButton</name>
    <message>
        <source>Clear</source>
        <translation type="obsolete">Очистити</translation>
    </message>
    <message>
        <source>None</source>
        <translation type="obsolete">Нічого</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../lxqtpower/lxqtpowerproviders.cpp" line="87"/>
        <location filename="../../lxqtpower/lxqtpowerproviders.cpp" line="137"/>
        <source>Power Manager Error</source>
        <translation>Збій менеджера живлення</translation>
    </message>
    <message>
        <location filename="../../lxqtpower/lxqtpowerproviders.cpp" line="88"/>
        <location filename="../../lxqtpower/lxqtpowerproviders.cpp" line="138"/>
        <source>QDBusInterface is invalid</source>
        <translation>QDBusInterface недійсний</translation>
    </message>
    <message>
        <location filename="../../lxqtpower/lxqtpowerproviders.cpp" line="102"/>
        <location filename="../../lxqtpower/lxqtpowerproviders.cpp" line="152"/>
        <source>Power Manager Error (D-BUS call)</source>
        <translation>Збій менеджера живлення (виклик D-BUS)</translation>
    </message>
</context>
<context>
    <name>about</name>
    <message>
        <source> About LXQt</source>
        <translation type="vanished"> Про LXQt</translation>
    </message>
    <message>
        <source>About</source>
        <comment>About dialog, Tab title </comment>
        <translation type="vanished">Про</translation>
    </message>
    <message>
        <source>Authors</source>
        <comment>About dialog, Tab title</comment>
        <translation type="vanished">Автори</translation>
    </message>
    <message>
        <source>Thanks</source>
        <comment>About dialog, Tab title</comment>
        <translation type="vanished">Подяка</translation>
    </message>
    <message>
        <source>Translations</source>
        <comment>About dialog, Tab title</comment>
        <translation type="vanished">Перекладачі</translation>
    </message>
    <message>
        <source>Technical Info</source>
        <comment>About dialog, Tab title</comment>
        <translation type="vanished">Технічна інформація</translation>
    </message>
</context>
</TS>
